JSON Operations
=================

This section encompasses a set of meticulously designed functions tailored for operations on JSON data structures. 
These functions are specifically crafted to manipulate and extract information from JSON objects. 

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   functions/json_operations/add_area
   functions/json_operations/add_center
   functions/json_operations/add_circularity
   functions/json_operations/cropping
   functions/json_operations/flipping
   functions/json_operations/rotation
   functions/json_operations/translation
   functions/json_operations/scale_json
   functions/json_operations/summary_json
   functions/polygon_downsampling/iterative_downsampling
   
 
